// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
import { Completer } from '@jupyterlab/completer';
import { Signal } from '@lumino/signaling';
export class LSPCompletionRenderer extends Completer.Renderer {
    constructor(options) {
        super();
        this.options = options;
        this.activeChanged = new Signal(this);
    }
    createCompletionItemNode(item, orderedTypes) {
        const li = super.createCompletionItemNode(item, orderedTypes);
        // make sure that an instance reference, and not an object copy is being used;
        item = item.self;
        // only monitor nodes that have item.self as others are not LazyCompletionItems
        // and only monitor those that need documentation retrieval
        if (item && !item.documentation) {
            let inactive = true;
            const observer = new MutationObserver(mutations => {
                if (li.classList.contains('jp-mod-active')) {
                    if (inactive) {
                        inactive = false;
                        this.activeChanged.emit(item);
                    }
                }
                else {
                    inactive = true;
                }
            });
            observer.observe(li, {
                attributes: true,
                attributeFilter: ['class']
            });
        }
        return li;
    }
    createDocumentationNode(item) {
        if (item.isDocumentationMarkdown) {
            this.options.markdownRenderer
                .renderModel({
                data: {
                    'text/markdown': item.documentation
                },
                trusted: false,
                metadata: {},
                setData(options) {
                    // empty
                }
            })
                .catch(this.options.console.warn);
            return this.options.markdownRenderer.node;
        }
        else {
            let node = document.createElement('div');
            node.textContent = item.documentation;
            return node;
        }
    }
}
//# sourceMappingURL=renderer.js.map